package com.yfd.platform.modules.auxcontrol.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import java.time.LocalDateTime;
import java.io.Serializable;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Data;
import lombok.EqualsAndHashCode;

/**
 * <p>
 * 变电站-辅控设备-告警记录
 * </p>
 *
 * @author zhengsl
 * @since 2025-04-23
 */
@Data
@EqualsAndHashCode(callSuper = false)
@TableName("fk_device_alarm_record")
public class DeviceAlarmRecord implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 记录ID
     */
    @TableId(type = IdType.ASSIGN_UUID)
    private String recordId;

    /**
     * 变电站ID
     */
    private String stationId;

    /**
     * 所属系统：01-在线监测 02-消防系统 03-安防系统 04-动环系统 05-锁控系统 06-辅控系统 07-照明系统
     */
    private String systemcode;

    /**
     * 告警时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private LocalDateTime alarmTime;

    /**
     * 告警设备ID
     */
    private String deviceId;

    /**
     * 告警设备名称
     */
    private String deviceName;

    /**
     * 告警信号ID
     */
    private String signalId;

    /**
     * 告警信号名称
     */
    private String signalName;

    /**
     * 告警类型
     */
    private String alarmType;

    /**
     * 告警等级：一般、严重、危急
     */
    private String alarmLevel;

    /**
     * 告警值
     */
    private String alarmValue;

    /**
     * 值单位
     */
    private String signalUnit;

    /**
     * 正常范围
     */
    private String normalRange;

    /**
     * 告警信息
     */
    private String alarmMessage;

    /**
     * 01-组件变色  02-系统弹窗 ，03-邮件通知 ，04-触发联动  可多选：01,02
     */
    private String noticeAction;

    /**
     * 邮件通知：[{name:"张三",email:"1122@163.com"}]
     */
    private String noticeEmails;

    /**
     * 触发联动：[{name:"XX联动",id:"12345678"}]
     */
    private String noticeLinkages;

    /**
     * 状态：01-初始生成 02-已执行动作 03-手动关闭 09-故障消除
     */
    private String status;

    /**
     * 备用1
     */
    private String custom1;

    /**
     * 备用2
     */
    private String custom2;

    /**
     * 备用3
     */
    private String custom3;

    /**
     * 告警分类：1-越限告警 2-设备报警
     */
    private String alarmClass;

    /**
     * 故障消除时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private LocalDateTime fixTime;

    /**
     * 区域标识
     */
    private String region;

    /**
     * 是否关闭告警0为关闭 1关闭
     */
    private String confirmClosure;

    /**
     * 操作人
     */
    private String operator;

    /**
     * 操作时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private LocalDateTime operationTime;

    /**
     * 告警分类：1-越限告警 2-设备报警 TODO 增加用于前端展示
     */
    @TableField(exist = false)
    private String alarmClassName;


    /**
     * 告警类型名称：如：温度过高、压力异常、电流过载 TODO 增加用于前端展示
     */
    @TableField(exist = false)
    private String alarmTypeName;

    /**
     * 告警等级名称：一般、严重、危急 TODO 增加用于前端展示
     */
    @TableField(exist = false)
    private String alarmLevelName;

    /**
     * 次数：TODO 增加用于前端展示
     */
    @TableField(exist = false)
    private String frequency;

    /**
     * 开始时间：TODO 增加用于前端展示
     */
    @TableField(exist = false)
    private String startDate;

    /**
     * 结束时间：TODO 增加用于前端展示
     */
    @TableField(exist = false)
    private String endDate;

    /**
     * 区域名称：TODO 增加用于前端展示
     */
    @TableField(exist = false)
    private String regionName;


    /**
     * 告警状态名称：TODO 增加用于前端展示
     */
    @TableField(exist = false)
    private String statusName;

    /**
     * 告警通知方式名称：01-系统弹窗 ，02-邮件通知 ，03-触发联动  可多选：01,02
     */
    @TableField(exist = false)
    private String noticeTypeName;
}
